Search for the bound of a confidence interval using permutation test statistics
confint_search(
start,
b,
n,
nmodel,
Xnull_,
y,
tr_,
new_tr_mat,
invS,
family,
family2,
Z,
type,
nsteps = 1000L,
weight = TRUE,
alpha = 0.05,
verbose = TRUE
)The estimated confidence interval bound
Numeric value indicating the starting value for the search procedure
Numeric value indicating the parameter estimate
Integer indicating the sample size
Integer. The number of models
Numeric matrix. The covariate design matrix with the treatment variable removed
Numeric vector of response variables
Numeric vector. The original random allocation (0s and 1s)
A matrix. Each column is a new random treatment allocation with 1s (treatment group) and 0s (control group)
A matrix. If using the weighted statistic then it should be the inverse covariance matrix of the observations
A string naming the link function
Matrix. Random effects design matrix describing cluster membership
String. Either "rw" for Romano-Wolf, "b" or "br" for bonferroni, "h" or "hr" for Holm, or "none"
Integer specifying the number of steps of the search procedure
Logical indicating whether to use the weighted (TRUE) or unweighted (FALSE) test statistic
The function generates (1-alpha)*100% confidence intervals. Default is 0.05.
Logical indicating whether to provide detailed output.