powered by
Extracts the dependent variable name from glm, lm, or mer model
outname_fit(fit)
A string with the name of the dependent variable from the model
A fitted model object of class glm, lm, or *merMod
out <- twoarm_sim() data <- out[[1]] fit1 <- lme4::glmer(y1 ~ treat + (1|cl) , data=data, family="poisson") outname_fit(fit1)
Run the code above in your browser using DataLab